@@ -45,6 +45,9 @@ ApplyKlass <- function(x,
 
 # sjekk og standardisere varible
   klass <- MakeChar(klass)
+  if (is.null(x)){
+    stop("The input vector is empty.")
+  }
   x <- MakeChar(x)
 
   if (is.null(date)){
